@@ -1,15 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Standard library imports
 from __future__ import unicode_literals
+
 import re
 
-# Third party imports
 from precise_bbcode.bbcode.exceptions import InvalidBBCodePlaholder
 from precise_bbcode.core.compat import with_metaclass
 
-# Local application / specific library imports
-
 
 class BBCodePlaceholderBase(type):
     """
@@ -37,7 +34,8 @@ class BBCodePlaceholderBase(type):
             )
         if not new_placeholder.name:
             raise InvalidBBCodePlaholder(
-                'The \'name\' attribute associated with InvalidBBCodePlaholder subclasses cannot be None'
+                'The \'name\' attribute associated with InvalidBBCodePlaholder subclasses '
+                'cannot be None'
             )
         if not re.match('^[\w]+$', new_placeholder.name):
             raise InvalidBBCodePlaholder(
